#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_TWOTONMB_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_TWOTONMB_HPP_INCLUDED

#include <boost/simd/constant/include/constants/twotonmb.hpp>

#endif
